@@ -12,7 +12,7 @@ import requests
 from requests import Response
 from requests.packages import urllib3  # noqa
 
-from applitools.common import Region, RunningSession, logger
+from applitools.common import DeviceName, IosDeviceName, Region, RunningSession, logger
 from applitools.common.client_event import LogSessionsClientEvents
 from applitools.common.errors import EyesError, EyesServiceUnavailableError
 from applitools.common.match import MatchResult
@@ -143,6 +143,9 @@ class ClientSession(object):
     def delete(self, url, **kwargs):
         return self._session.delete(url, **kwargs)
 
+    def use_proxies(self, proxies):
+        self._session.proxies = proxies
+
 
 @attr.s
 class _RequestCommunicator(object):
@@ -316,6 +319,10 @@ class ServerConnector(object):
     RENDER_STATUS = "/render-status"
     RENDER = "/render"
     RENDERER_INFO = "/job-info"
+    DEVICES_SIZES = {
+        IosDeviceName: "/ios-devices-sizes",
+        DeviceName: "/emulated-devices-sizes",
+    }
 
     _is_session_started = False
     _retry_limiter = _SessionRetryLimiter()
@@ -329,6 +336,7 @@ class ServerConnector(object):
         """
         self._render_info = None  # type: Optional[RenderingInfo]
         self._ua_string = None  # type: Optional[Text]
+        self._proxies = None
 
         if client_session:
             self._com = _RequestCommunicator(
@@ -351,6 +359,9 @@ class ServerConnector(object):
         if ua_string:
             self._ua_string = ua_string
         self.DEFAULT_HEADERS["x-applitools-eyes-client"] = full_agent_id
+        if conf.proxy is not None:
+            self._proxies = {"http": conf.proxy.url, "https": conf.proxy.url}
+            self._com.client_session.use_proxies(self._proxies)
 
     @property
     def server_url(self):
@@ -664,11 +675,20 @@ class ServerConnector(object):
     @retry()
     def _try_download_resources(self, headers, timeout_sec, url, cookies):
         response = requests.get(
-            url, headers=headers, cookies=cookies, timeout=timeout_sec, verify=False
+            url,
+            headers=headers,
+            cookies=cookies,
+            proxies=self._proxies,
+            timeout=timeout_sec,
+            verify=False,
         )
         if response.status_code == requests.codes.not_acceptable:
             response = requests.get(
-                url, timeout=timeout_sec, cookies=cookies, verify=False
+                url,
+                cookies=cookies,
+                proxies=self._proxies,
+                timeout=timeout_sec,
+                verify=False,
             )
         return response
 
@@ -725,6 +745,11 @@ class ServerConnector(object):
             for d in resp.json()
         ]
 
+    @retry()
+    def get_devices_sizes(self, device_type):
+        response = self._ufg_request("get", self.DEVICES_SIZES[device_type])
+        return response.raise_for_status() or response.json()
+
     @retry()
     def check_resource_status(self, resources):
         hashes = [{"hashFormat": r.hash_format, "hash": r.hash} for r in resources]
